.. image:: https://travis-ci.org/seisman/sphinx-cjkspace.svg?branch=master
    :target: https://travis-ci.org/seisman/sphinx-cjkspace

sphinx-cjkspace
===============

A Sphinx extention that remove extra spaces between CJK characters due to
newlines in reStructuredText files.
